@@ -3,6 +3,7 @@
 
 #include <gconf/gconf-client.h>
 #include <hildon/hildon-program.h>
+#include <libxml/xmlreader.h>
 
 #include "note_list_store.h"
 
@@ -10,12 +11,13 @@ typedef struct
 {
 	const gchar   *user_path;
 	GList         *open_notes;
-	gint           font_size;
 	GConfClient   *client;
 	HildonProgram *program;
 	gboolean	   fullscreen;
+	gboolean       portrait;
 	HildonWindow  *search_window;
 	NoteListStore *note_store;
+	xmlTextReader *reader;
 } AppData;
 
 AppData* app_data_get(void);
