@@ -580,7 +580,7 @@ GtkWidget* create_mainwin(Note *note) {
 
 	/* SCROLLED WINDOW */
 #ifdef HILDON_HAS_APP_MENU
-	g_printerr("Using pannable area");
+	g_printerr("Using pannable area\n");
 	scrolledwindow1 = hildon_pannable_area_new();
 #else
 	scrolledwindow1 = gtk_scrolled_window_new(NULL, NULL);
@@ -636,6 +636,14 @@ GtkWidget* create_mainwin(Note *note) {
 		g_object_set(link, "foreground-gdk", &color, NULL);
 	}
 
+	/* Set initial orientation */
+#ifdef HILDON_HAS_APP_MENU
+	if (app_data->portrait) {
+		hildon_gtk_window_set_portrait_flags(mainwin, HILDON_PORTRAIT_MODE_REQUEST);
+	} else {
+		hildon_gtk_window_set_portrait_flags(mainwin, HILDON_PORTRAIT_MODE_SUPPORT);
+	}
+#endif
 
 	/* Enable support for tap and hold on the textview */
 	/* TODO: This is deactivated for now, because it's not included in upstream Gtk
@@ -811,10 +819,6 @@ GtkWidget* create_mainwin(Note *note) {
 			G_CALLBACK (on_link_internal_tag_event),
 			note);
 
-#ifdef HILDON_HAS_APP_MENU
-	hildon_gtk_window_set_portrait_flags(GTK_WINDOW(mainwin), HILDON_PORTRAIT_MODE_SUPPORT);
-#endif
-
 	return mainwin;
 }
 
