@@ -23,7 +23,9 @@
 #include <libosso.h>
 #include <mce/dbus-names.h>
 #include <mce/mode-names.h>
+#ifdef HILDON_HAS_APP_MENU
 #include <hildon/hildon-gtk.h>
+#endif
 
 #include "app_data.h"
 #include "settings.h"
@@ -104,6 +106,13 @@ dbus_handle_mce_message(DBusConnection *con, DBusMessage *msg, gpointer data)
 	return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
 }
 
+static gint
+orientation_handler(const gchar *iface, const gchar *method, GArray *args, gpointer data, osso_rpc_t *retval)
+{
+	g_printerr("IFACE: %s\n", iface);
+	g_printerr("METHOD: %s\n", method);
+}
+
 /*
 gboolean
 check_device_position(DBusConnection *connection){
@@ -237,7 +246,7 @@ main (int argc, char *argv[])
   }
 
   /* Get the DBus connection */
-  gpointer con = osso_get_sys_dbus_connection(osso_context);
+  DBusConnection *con = osso_get_sys_dbus_connection(osso_context);
 
 #ifdef HILDON_HAS_APP_MENU
   /* Get current orientation from DBus and save into app_data */
