@@ -520,7 +520,14 @@ HildonWindow* search_window_create(SearchWindowData *window_data)
 #ifdef HILDON_HAS_APP_MENU
 	g_signal_connect(button_sort_by_title, "toggled", G_CALLBACK(on_sort_by_title_changed), sorted_store);
 	g_signal_connect(button_sort_by_date, "toggled", G_CALLBACK(on_sort_by_date_changed), sorted_store);
-	hildon_gtk_window_set_portrait_flags(GTK_WINDOW(win), HILDON_PORTRAIT_MODE_SUPPORT);
+
+	/* Set initial orientation */
+	if (app_data->portrait) {
+		hildon_gtk_window_set_portrait_flags(GTK_WINDOW(win), HILDON_PORTRAIT_MODE_REQUEST);
+	} else {
+		hildon_gtk_window_set_portrait_flags(GTK_WINDOW(win), HILDON_PORTRAIT_MODE_SUPPORT);
+	}
+
 #endif
 
 	app_data = app_data_get();
